@@ -1,6 +1,5 @@
 from tempfile import NamedTemporaryFile
 
-import vaex
 from minio import Minio
 from vaex.dataframe import DataFrame
 
@@ -45,8 +44,7 @@ class ObjectStore:
         """Uploads a Vaex dataframe to Minio at the specified object_name location"""
         ext = get_file_extension(object_name)
         with NamedTemporaryFile(suffix=ext) as f:
-            with vaex.progress.tree("vaex", title="Writing data for upload"):
-                df.export(f.name)
+            df.export(f.name)
             self.create_project_run_object(
                 object_name=object_name,
                 file_path=f.name,
