@@ -32,9 +32,9 @@ def test_threaded_logging_and_upload(
     """
     num_records = 32
     num_logs = 20
-    num_emb = 50
+    num_embs = 50
     _log_text_classification_data(
-        num_records=num_records, num_logs=num_logs, num_emb=num_emb
+        num_records=num_records, num_logs=num_logs, num_embs=num_embs
     )
     try:
         # Equivalent to the users `finish` call, but we don't want to clean up files yet
@@ -59,9 +59,9 @@ def test_multi_label_logging(
     set_test_config(task_type=TaskType.text_multi_label)
     num_records = 32
     num_logs = 20
-    num_emb = 50
+    num_embs = 50
     _log_text_classification_data(
-        num_records=num_records, num_logs=num_logs, num_emb=num_emb, multi_label=True
+        num_records=num_records, num_logs=num_logs, num_embs=num_embs, multi_label=True
     )
     try:
         # Equivalent to the users `finish` call, but we don't want to clean up files yet
@@ -109,12 +109,12 @@ def test_metadata_logging_different_splits(
     """
     training_data = input_data(meta={"training_meta": [1, 2]})
     dataquality.set_labels_for_run(training_data["labels"])
-    dataquality.log_input_data(**training_data)
+    dataquality.log_data_samples(**training_data)
     test_data = input_data(split="test", meta={"test_meta": ["foo", "bar"]})
-    dataquality.log_input_data(**test_data)
+    dataquality.log_data_samples(**test_data)
 
     output_data = {
-        "emb": np.random.rand(2, 100),
+        "embs": np.random.rand(2, 100),
         "logits": np.random.rand(2, 5),
         "ids": [1, 2],
         "split": "training",
@@ -207,24 +207,24 @@ def test_logging_inference_run(
     inference_data = input_data(
         split="inference", meta={"inference_meta_1": [3.14, 42]}
     )
-    dataquality.log_input_data(**inference_data)
+    dataquality.log_data_samples(**inference_data)
     inference_data = input_data(split="inference", inference_name="last-week-customers")
-    dataquality.log_input_data(**inference_data)
+    dataquality.log_data_samples(**inference_data)
 
     dataquality.set_split("inference", inference_name="all-customers")
-    emb_1 = np.random.rand(2, 100)
+    embs_1 = np.random.rand(2, 100)
     logits_1 = np.random.rand(2, 5)
     output_data = {
-        "emb": emb_1,
+        "embs": embs_1,
         "logits": logits_1,
         "ids": [1, 2],
     }
     dataquality.log_model_outputs(**output_data)
     dataquality.set_split("inference", inference_name="last-week-customers")
-    emb_2 = np.random.rand(2, 100)
+    embs_2 = np.random.rand(2, 100)
     logits_2 = np.random.rand(2, 5)
     output_data = {
-        "emb": emb_2,
+        "embs": embs_2,
         "logits": logits_2,
         "ids": [1, 2],
     }
@@ -247,8 +247,8 @@ def test_logging_inference_run(
         f"{TEST_PATH}/inference/last-week-customers/emb/emb.hdf5"
     )
 
-    assert (inference_emb_1.emb.to_numpy() == emb_1).all()
-    assert (inference_emb_2.emb.to_numpy() == emb_2).all()
+    assert (inference_emb_1.emb.to_numpy() == embs_1).all()
+    assert (inference_emb_2.emb.to_numpy() == embs_2).all()
 
     inference_prob_1 = vaex.open(f"{TEST_PATH}/inference/all-customers/prob/prob.hdf5")
     inference_prob_2 = vaex.open(
@@ -278,27 +278,32 @@ def test_logging_train_test_inference(
     """
     dataquality.set_labels_for_run(["APPLE", "ORANGE"])
     training_data = input_data(meta={"training_meta": [1.414, 123]})
-    dataquality.log_input_data(**training_data)
+    dataquality.log_data_samples(**training_data)
     test_data = input_data(split="test", meta={"test_meta": [3.14, 42]})
-    dataquality.log_input_data(**test_data)
+    dataquality.log_data_samples(**test_data)
     inference_data = input_data(split="inference")
-    dataquality.log_input_data(**inference_data)
+    dataquality.log_data_samples(**inference_data)
 
     dataquality.set_split("training")
-    train_emb = np.random.rand(2, 100)
+    train_embs = np.random.rand(2, 100)
     train_logits = np.random.rand(2, 5)
-    output_data = {"emb": train_emb, "logits": train_logits, "ids": [1, 2], "epoch": 0}
+    output_data = {
+        "embs": train_embs,
+        "logits": train_logits,
+        "ids": [1, 2],
+        "epoch": 0,
+    }
     dataquality.log_model_outputs(**output_data)
     dataquality.set_split("test")
-    test_emb = np.random.rand(2, 100)
+    test_embs = np.random.rand(2, 100)
     test_logits = np.random.rand(2, 5)
-    output_data = {"emb": test_emb, "logits": test_logits, "ids": [1, 2], "epoch": 0}
+    output_data = {"embs": test_embs, "logits": test_logits, "ids": [1, 2], "epoch": 0}
     dataquality.log_model_outputs(**output_data)
     dataquality.set_split("inference", inference_name="all-customers")
-    inf_emb = np.random.rand(2, 100)
+    inf_embs = np.random.rand(2, 100)
     inf_logits = np.random.rand(2, 5)
     output_data = {
-        "emb": inf_emb,
+        "embs": inf_embs,
         "logits": inf_logits,
         "ids": [1, 2],
     }
@@ -320,9 +325,9 @@ def test_logging_train_test_inference(
     test_emb_data = vaex.open(f"{TEST_PATH}/test/0/emb/emb.hdf5")
     inference_emb_data = vaex.open(f"{TEST_PATH}/inference/all-customers/emb/emb.hdf5")
 
-    assert (train_emb_data.emb.to_numpy() == train_emb).all()
-    assert (test_emb_data.emb.to_numpy() == test_emb).all()
-    assert (inference_emb_data.emb.to_numpy() == inf_emb).all()
+    assert (train_emb_data.emb.to_numpy() == train_embs).all()
+    assert (test_emb_data.emb.to_numpy() == test_embs).all()
+    assert (inference_emb_data.emb.to_numpy() == inf_embs).all()
 
     train_prob_data = vaex.open(f"{TEST_PATH}/training/0/prob/prob.hdf5")
     test_prob_data = vaex.open(f"{TEST_PATH}/test/0/prob/prob.hdf5")
@@ -330,6 +335,14 @@ def test_logging_train_test_inference(
         f"{TEST_PATH}/inference/all-customers/prob/prob.hdf5"
     )
 
+    assert "training_meta" in train_data.get_column_names()
+    assert "training_meta" not in test_data.get_column_names()
+    assert "training_meta" not in inference_data.get_column_names()
+
+    assert "test_meta" not in train_data.get_column_names()
+    assert "test_meta" in test_data.get_column_names()
+    assert "test_meta" not in inference_data.get_column_names()
+
     assert "logits" not in train_prob_data.get_column_names()
     assert "logits" not in test_prob_data.get_column_names()
     assert "logits" not in inference_prob_data.get_column_names()
@@ -346,3 +359,18 @@ def test_logging_train_test_inference(
         inference_prob_data.prob.to_numpy()
         == dataquality.get_model_logger()().convert_logits_to_probs(inf_logits)
     ).all()
+
+
+def test_prob_only(set_test_config) -> None:
+    """Tests that the last_epoch is determined at the split level"""
+    logger = dataquality.get_data_logger()
+    logger.logger_config.last_epoch = 5
+    train_split_runs = ["0", "1", "5", "3", "4"]
+    val_split_runs = ["0", "1", "3", "4"]
+    test_split_runs = ["0"]
+
+    assert logger.prob_only(train_split_runs, "training", "0")
+    assert not logger.prob_only(train_split_runs, "training", "5")
+    assert logger.prob_only(val_split_runs, "validation", "0")
+    assert not logger.prob_only(val_split_runs, "validation", "5")
+    assert not logger.prob_only(test_split_runs, "test", "0")
