@@ -9,7 +9,8 @@ from spacy.pipeline.ner import EntityRecognizer
 from spacy.training import Example
 
 import dataquality
-from dataquality.core.integrations.spacy import (
+from dataquality.exceptions import GalileoException
+from dataquality.integrations.spacy import (
     GalileoEntityRecognizer,
     log_input_examples,
     unwatch,
@@ -24,6 +25,7 @@ from tests.utils.spacy_integration import load_ner_data_from_local, train_model
 from tests.utils.spacy_integration_constants import (
     LONG_SHORT_DATA,
     LONG_TRAIN_DATA,
+    MISALIGNED_SPAN_DATA,
     NER_CLASS_LABELS,
     NER_TEST_DATA,
     NER_TRAINING_DATA,
@@ -31,9 +33,46 @@ from tests.utils.spacy_integration_constants import (
 )
 
 
+def test_log_input_examples_without_watch(set_test_config, cleanup_after_use):
+    text_ner_logger_config.reset()
+    set_test_config(task_type=TaskType.text_ner)
+
+    with pytest.raises(GalileoException) as e:
+        log_input_examples(NER_TRAINING_DATA, split="training")
+    assert (
+        e.value.args[0]
+        == "Galileo does not have any logged labels. Did you forget to call "
+        "watch(nlp) before log_input_examples(...)?"
+    )
+
+
+def test_log_input_list_of_tuples(set_test_config, cleanup_after_use):
+    text_ner_logger_config.reset()
+    set_test_config(task_type=TaskType.text_ner)
+
+    nlp = spacy.blank("en")
+    nlp.add_pipe("ner")
+
+    training_examples = []
+    for text, annotations in NER_TRAINING_DATA:
+        doc = nlp.make_doc(text)
+        training_examples.append(Example.from_dict(doc, annotations))
+    nlp.initialize(lambda: training_examples)
+
+    watch(nlp)
+
+    with pytest.raises(GalileoException) as e:
+        log_input_examples(NER_TRAINING_DATA, "training")
+    assert (
+        e.value.args[0]
+        == "Expected a <class 'spacy.training.example.Example'>. Received "
+        "<class 'tuple'>"
+    )
+
+
 def test_log_input_examples(set_test_config, cleanup_after_use):
+    text_ner_logger_config.reset()
     set_test_config(task_type=TaskType.text_ner)
-    text_ner_logger_config.gold_spans = {}
     nlp = spacy.blank("en")
     nlp.add_pipe("ner")
 
@@ -219,7 +258,7 @@ def test_long_sample(
         logger: TextNERModelLogger = args[0]
         assert len(logger.ids) == len(samples)
         assert len(logger.logits) == len(samples)
-        assert len(logger.emb) == len(samples)
+        assert len(logger.embs) == len(samples)
 
     TextNERModelLogger.log = new_log
 
@@ -266,3 +305,98 @@ def test_inference_split_raises_warning(
                 "logging"
             )
         assert not mocked_model_logger_log.called
+
+
+def test_spacy_does_not_log_misaligned_entities(cleanup_after_use, set_test_config):
+    TextNERModelLogger.logger_config.reset()
+    set_test_config(task_type=TaskType.text_ner)
+
+    nlp = spacy.blank("en")
+    nlp.add_pipe("ner", last=True)
+
+    def make_examples(data):
+        examples = []
+        for text, annotations in data:
+            doc = nlp.make_doc(text)
+            examples.append(Example.from_dict(doc, annotations))
+        return examples
+
+    nlp.initialize(lambda: make_examples(NER_TRAINING_DATA))
+
+    training_examples = make_examples(MISALIGNED_SPAN_DATA)
+
+    assert len(training_examples[0].reference.ents) == 0
+
+    nlp.initialize(lambda: training_examples)
+
+    # Galileo code
+    watch(nlp)
+    log_input_examples(training_examples, "training")
+
+    logged_gold_spans = dataquality.get_data_logger().logger_config.gold_spans
+    assert len(logged_gold_spans["training_0"]) == 0
+
+
+@pytest.mark.parametrize(
+    "training_data",
+    [
+        NER_TRAINING_DATA,
+        [(text, {"entities": []}) for text, entities in NER_TRAINING_DATA],
+        [
+            (text, entities if i != 1 else {"entities": []})
+            for i, (text, entities) in enumerate(NER_TRAINING_DATA)
+        ],
+    ],
+)
+def test_log_input_examples_have_no_gold_spans(
+    set_test_config, cleanup_after_use, training_data
+):
+    TextNERModelLogger.logger_config.reset()
+    set_test_config(task_type=TaskType.text_ner)
+    nlp = spacy.blank("en")
+    nlp.add_pipe("ner")
+
+    def make_examples(data):
+        examples = []
+        for text, annotations in data:
+            doc = nlp.make_doc(text)
+            examples.append(Example.from_dict(doc, annotations))
+        return examples
+
+    nlp.initialize(lambda: make_examples(NER_TRAINING_DATA))
+
+    training_examples = make_examples(training_data)
+
+    watch(nlp)
+    log_input_examples(training_examples, "training")
+
+    samples_logged_gold_spans = dataquality.get_data_logger().logger_config.gold_spans
+
+    for i, (_, logged_gold_spans) in enumerate(samples_logged_gold_spans.items()):
+        original_spans = training_examples[i].reference.ents
+
+        assert len(logged_gold_spans) == len(original_spans)
+        for logged_gold_span, original_span in zip(logged_gold_spans, original_spans):
+            assert logged_gold_span[0] == original_span.start
+            assert logged_gold_span[1] == original_span.end
+            assert logged_gold_span[2] == original_span.label_
+
+
+def test_watch_nlp_with_no_gold_labels(set_test_config, cleanup_after_use):
+    TextNERModelLogger.logger_config.reset()
+    set_test_config(task_type=TaskType.text_ner)
+
+    nlp = spacy.blank("en")
+    nlp.add_pipe("ner")
+    nlp.initialize()
+
+    with pytest.raises(GalileoException) as e:
+        watch(nlp)
+    assert e.value.args[0] == (
+        "Your nlp seems to not have been initialized with any "
+        "ground truth spans. Galileo needs all labels to have "
+        "been added to the model before calling "
+        "watch(nlp). Please run `nlp.initialize(lambda: your_examples)` over a "
+        "list of examples that include all of the gold spans you plan to make "
+        "predictions over."
+    )
